@@ -9,14 +9,15 @@ Usage::
     data: AutoScalingGroupConfigurationTypeDef = {...}
     ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -27,21 +28,29 @@ __all__ = (
     "AutoScalingGroupConfigurationTypeDef",
     "AutoScalingGroupRecommendationOptionTypeDef",
     "AutoScalingGroupRecommendationTypeDef",
+    "ExportDestinationTypeDef",
     "GetRecommendationErrorTypeDef",
     "InstanceRecommendationOptionTypeDef",
     "InstanceRecommendationTypeDef",
     "ProjectedMetricTypeDef",
+    "RecommendationExportJobTypeDef",
     "RecommendationSourceTypeDef",
     "RecommendationSummaryTypeDef",
     "RecommendedOptionProjectedMetricTypeDef",
+    "S3DestinationTypeDef",
     "SummaryTypeDef",
     "UtilizationMetricTypeDef",
+    "DescribeRecommendationExportJobsResponseTypeDef",
+    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
+    "ExportEC2InstanceRecommendationsResponseTypeDef",
     "FilterTypeDef",
     "GetAutoScalingGroupRecommendationsResponseTypeDef",
     "GetEC2InstanceRecommendationsResponseTypeDef",
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
     "GetEnrollmentStatusResponseTypeDef",
     "GetRecommendationSummariesResponseTypeDef",
+    "JobFilterTypeDef",
+    "S3DestinationConfigTypeDef",
     "UpdateEnrollmentStatusResponseTypeDef",
 )
 
@@ -78,6 +87,10 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
     total=False,
 )
 
+ExportDestinationTypeDef = TypedDict(
+    "ExportDestinationTypeDef", {"s3": "S3DestinationTypeDef"}, total=False
+)
+
 GetRecommendationErrorTypeDef = TypedDict(
     "GetRecommendationErrorTypeDef", {"identifier": str, "code": str, "message": str}, total=False
 )
@@ -116,6 +129,20 @@ ProjectedMetricTypeDef = TypedDict(
     total=False,
 )
 
+RecommendationExportJobTypeDef = TypedDict(
+    "RecommendationExportJobTypeDef",
+    {
+        "jobId": str,
+        "destination": "ExportDestinationTypeDef",
+        "resourceType": Literal["Ec2Instance", "AutoScalingGroup"],
+        "status": Literal["Queued", "InProgress", "Complete", "Failed"],
+        "creationTimestamp": datetime,
+        "lastUpdatedTimestamp": datetime,
+        "failureReason": str,
+    },
+    total=False,
+)
+
 RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
@@ -145,6 +172,10 @@ RecommendedOptionProjectedMetricTypeDef = TypedDict(
     total=False,
 )
 
+S3DestinationTypeDef = TypedDict(
+    "S3DestinationTypeDef", {"bucket": str, "key": str, "metadataKey": str}, total=False
+)
+
 SummaryTypeDef = TypedDict(
     "SummaryTypeDef",
     {
@@ -160,6 +191,24 @@ UtilizationMetricTypeDef = TypedDict(
     total=False,
 )
 
+DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
+    "DescribeRecommendationExportJobsResponseTypeDef",
+    {"recommendationExportJobs": List["RecommendationExportJobTypeDef"], "nextToken": str},
+    total=False,
+)
+
+ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
+    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
+    {"jobId": str, "s3Destination": "S3DestinationTypeDef"},
+    total=False,
+)
+
+ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
+    "ExportEC2InstanceRecommendationsResponseTypeDef",
+    {"jobId": str, "s3Destination": "S3DestinationTypeDef"},
+    total=False,
+)
+
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {"name": Literal["Finding", "RecommendationSourceType"], "values": List[str]},
@@ -208,6 +257,16 @@ GetRecommendationSummariesResponseTypeDef = TypedDict(
     total=False,
 )
 
+JobFilterTypeDef = TypedDict(
+    "JobFilterTypeDef",
+    {"name": Literal["ResourceType", "JobStatus"], "values": List[str]},
+    total=False,
+)
+
+S3DestinationConfigTypeDef = TypedDict(
+    "S3DestinationConfigTypeDef", {"bucket": str, "keyPrefix": str}, total=False
+)
+
 UpdateEnrollmentStatusResponseTypeDef = TypedDict(
     "UpdateEnrollmentStatusResponseTypeDef",
     {"status": Literal["Active", "Inactive", "Pending", "Failed"], "statusReason": str},
